import re
import numpy as np
import string
import pickle

def load_data():    
    with open("characters", 'rb') as f:
        my_list = pickle.load(f)
    np_data = np.array(my_list)
    w = np_data.reshape(26,6)
    #create a map between the letters and 
    d = dict(zip(list(string.ascii_lowercase),range(0,27)))
    return w,d
def printbig(st):
    w,d = load_data()
    inp=st
    res=""
    for i in range(5):
        for char in list(inp):
            if (char == " "):
                res+= "\t"
            else:
                res += w[d.get(char)][i]
        res+="\n"
    print(res)
    


from setuptools import setup

setup(
    # Needed to silence warnings
    name='printbig',
    url='https://github.com/AlexAndrei98/testpackage',
    author='Alex Andrei',
    author_email='alexandrei1998@hotmail.it',
    # Needed to actually package something
    packages=['printbig'],
    # Needed for dependencies
    install_requires=['numpy','pickle','string'],
    # *strongly* suggested for sharing
    version='0.5.2',
    license='MIT',
    description='An example of a python package from pre-existing code',
    # We will also need a readme eventually (there will be a warning)
    long_description=open('README.txt').read(),
    # if there are any scripts
)